pyesmda.ESMDA\_RS
=================

.. currentmodule:: pyesmda

.. autoclass:: ESMDA_RS
   :members:                                    <-- add at least this line
   :private-members:
   :show-inheritance:                           <-- plus I want to show inheritance...
   :inherited-members:                          <-- ...and inherited members too

   
   .. automethod:: __init__

   
   .. rubric:: Public methods summary

   .. autosummary::
   
      ~ESMDA_RS.__delattr__
      ~ESMDA_RS.__dir__
      ~ESMDA_RS.__eq__
      ~ESMDA_RS.__format__
      ~ESMDA_RS.__ge__
      ~ESMDA_RS.__getattribute__
      ~ESMDA_RS.__gt__
      ~ESMDA_RS.__hash__
      ~ESMDA_RS.__init__
      ~ESMDA_RS.__init_subclass__
      ~ESMDA_RS.__le__
      ~ESMDA_RS.__lt__
      ~ESMDA_RS.__ne__
      ~ESMDA_RS.__new__
      ~ESMDA_RS.__reduce__
      ~ESMDA_RS.__reduce_ex__
      ~ESMDA_RS.__repr__
      ~ESMDA_RS.__setattr__
      ~ESMDA_RS.__sizeof__
      ~ESMDA_RS.__str__
      ~ESMDA_RS.__subclasshook__
      ~ESMDA_RS._analyse
      ~ESMDA_RS._apply_bounds
      ~ESMDA_RS._approximate_covariance_matrices
      ~ESMDA_RS._compute_initial_inflation_factor
      ~ESMDA_RS._forecast
      ~ESMDA_RS._get_batch_m_update
      ~ESMDA_RS._is_unity_reached
      ~ESMDA_RS._is_valid_parameter_change
      ~ESMDA_RS._local_analyse
      ~ESMDA_RS._pertrub
      ~ESMDA_RS._set_n_assimilations
      ~ESMDA_RS._solve
      ~ESMDA_RS._solve_locally
      ~ESMDA_RS.set_cov_obs_inflation_factors
      ~ESMDA_RS.solve
   
   
   

   .. rubric:: Methods definition